@@ -12,7 +12,7 @@ from cqh_file.utils import get_md5
 class ClientLoop(object):
     def __init__(self, url, dir, sleep, delete):
         self.url = url
-        self.dir = dir
+        self.dir_list = dir
         self.sleep = sleep
         self.delete = delete
         self.session = requests.Session()
@@ -24,13 +24,13 @@ class ClientLoop(object):
         res = self.session.post(url, **kwargs)
         return res
 
-    def read_serve_list(self):
+    def read_serve_list(self, dir):
         url = self.path_url("/list")
         res = self.request_url(url, json={})
-        click.echo("serve, status_code:{} text:{}".format(res.status_code, res.text))
-        click.echo("serve, res:  cost:{}".format(res.elapsed.total_seconds()))
+        click.echo("dir: [{}],serve, status_code:{} text:{}".format(dir,res.status_code, res.text))
+        click.echo("dir:[{}],serve, res:  cost:{}".format(dir,res.elapsed.total_seconds()))
         j = res.json()
-        with open(os.path.join(self.dir, ".serve.json"), 'w', encoding='utf-8') as f:
+        with open(os.path.join(dir, ".serve.json"), 'w', encoding='utf-8') as f:
             f.write(json.dumps(j, ensure_ascii=False, indent=2))
         return j
     
@@ -40,13 +40,13 @@ class ClientLoop(object):
             raise ValueError("{} status code error {}".format(prefix, status_code))
         
 
-    def read_client_md5_value(self):
+    def read_client_md5_value(self, dir):
         d = {}
-        for name in os.listdir(self.dir):
-            file_path = os.path.join(self.dir, name)
+        for name in os.listdir(dir):
+            file_path = os.path.join(dir, name)
             if os.path.exists(file_path) and os.path.isfile(file_path) and name[0] != ".":
                 d[name] = get_md5(file_path)
-        with open(os.path.join(self.dir, ".client.json"), 'w', encoding='utf-8') as f:
+        with open(os.path.join(dir, ".client.json"), 'w', encoding='utf-8') as f:
             f.write(json.dumps(d, ensure_ascii=False, indent=2))
         return d
 
@@ -59,42 +59,50 @@ class ClientLoop(object):
             click.echo("sleep {}, {}".format(self.sleep, datetime.datetime.now().strftime("%Y-%m-%d %H:%M:%S")))
             time.sleep(self.sleep)
     
-    def try_delete(self):
+    def try_delete(self, dir):
         if not self.delete:
             return
-        for name in os.listdir(self.dir):
-            file_path = os.path.join(self.dir, name)
+        for name in os.listdir(dir):
+            file_path = os.path.join(dir, name)
             if os.path.isfile(file_path):
                 os.remove(file_path)
                 click.echo("delete name: [{}]".format(name))
 
     def run_once(self):
-        self.try_delete()
-        j = self.read_serve_list()
-        client_d = self.read_client_md5_value()
-        # 遍历所有的名字,检查需不需要下载,然后下载就好了
-        count = 0
-        for name, md5_value in j.items():
-            if name not in client_d:
-                count +=1
-                self.download(name, client_d)
-                continue
-            if client_d[name] != md5_value:
-                count +=1
-                self.download(name, client_d)
-        click.echo("download file count: {}".format(count))
-        self.read_client_md5_value()
+        for dir in self.dir_list:
+            if not os.path.exists(dir):
+                os.makedirs(dir)
+                click.echo("create dir {}".format(dir))
+            self.try_delete(dir)
+            j = self.read_serve_list(dir)
+            client_d = self.read_client_md5_value(dir)
+            # 遍历所有的名字,检查需不需要下载,然后下载就好了
+            count = 0
+            for name, md5_value in j.items():
+                if name not in client_d:
+                    count +=1
+                    self.download(name, client_d, dir)
+                    continue
+                if client_d[name] != md5_value:
+                    count +=1
+                    self.download(name, client_d, dir)
+            click.echo("[{}],download file count: {}".format(dir, count))
+            click.echo("="*80)
+            click.echo("[{}] complete".format(dir))
+            click.echo("="*80)
+            self.read_client_md5_value(dir)
     
-    def download(self, name,d):
+    def download(self, name,d, dir):
+        prefix = "dir:[{}]".format(dir)
         url = self.path_url("/download")
         res = self.request_url(url, json={"name": name})
-        click.echo("download name:{}, cost:{}".format(name, res.elapsed.total_seconds()))
+        click.echo("{}, download name:{}, cost:{}".format(prefix, name, res.elapsed.total_seconds()))
         j = res.json()
         if res.status_code != 200 or j['code']!=0:
-            click.echo("download error {}".format(res.status_code, res.text))
+            click.echo("{},download error {}".format(prefix, res.status_code, res.text))
             return
         base64_str = j['data']
         raw_data = base64.b64decode(base64_str)
-        with open(os.path.join(self.dir, name), 'wb') as f:
+        with open(os.path.join(dir, name), 'wb') as f:
             f.write(raw_data)
 
